@@ -118,6 +118,9 @@
 #include <sys/stat.h>
 #include <syslog.h>
 
+#include "string/strcmp/streq.h"
+
+
 #define IMMEDIATE_CHANGE	/* Expire newly created password, must be changed
 				 * immediately upon next login */
 #define HAVE_QUOTAS		/* Obvious */
@@ -291,12 +294,10 @@ main (void)
 	  printf ("Home Directory [%s/%s]: ", DEFAULT_HOME, usrname);
 	  fflush (stdout);
 	  safeget (dir, sizeof (dir));
-	  if (!strlen (dir))
-	    {			/* hit return */
-	      sprintf (dir, "%s/%s", DEFAULT_HOME, usrname);
-	    }
+	  if (!strlen(dir))  /* hit return */
+	    sprintf(dir, "%s/%s", DEFAULT_HOME, usrname);
 	  else if (dir[strlen (dir) - 1] == '/')
-	    sprintf (dir+strlen(dir), "%s", usrname);
+	    strcat(dir, usrname);
 	}
       else
 	{
@@ -308,7 +309,7 @@ main (void)
       fflush (stdout);
       safeget (shell, sizeof (shell));
       if (!strlen (shell))
-	sprintf (shell, "%s", DEFAULT_SHELL);
+	strcpy(shell, DEFAULT_SHELL);
       else
 	{
 	  char *sh;
@@ -316,7 +317,7 @@ main (void)
 #ifdef HAVE_GETUSERSHELL
 	  setusershell ();
 	  while ((sh = getusershell ()) != NULL)
-	    if (!strcmp (shell, sh))
+	    if (streq(shell, sh))
 	      ok = 1;
 	  endusershell ();
 #endif
@@ -327,7 +328,7 @@ main (void)
 	      else
 		{
 		  printf ("Shell NOT in /etc/shells, DEFAULT used\n");
-		  sprintf (shell, "%s", DEFAULT_SHELL);
+		  strcpy(shell, DEFAULT_SHELL);
 		}
 	    }
 	}
@@ -491,12 +492,12 @@ safeget (char *buf, int maxlen)
       bad = (!isalnum (c) && (c != '_') && (c != ' '));
       *(buf++) = c;
     }
-  *buf = '\0';
+  stpcpy(buf, "");
 
   if (bad)
     {
       printf ("\nString contained banned character. Please stick to alphanumerics.\n");
-      *bstart = '\0';
+      stpcpy(bstart, "");
     }
 }
 
