@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023, Alejandro Colomar <alx@kernel.org>
+// SPDX-FileCopyrightText: 2023-2024, Alejandro Colomar <alx@kernel.org>
 // SPDX-License-Identifier: BSD-3-Clause
 
 
@@ -11,8 +11,8 @@
 #include <errno.h>
 #include <limits.h>
 #include <stddef.h>
-#include <stdlib.h>
 
+#include "search/sort/qsort.h"
 #include "sizeof.h"
 
 
@@ -27,8 +27,6 @@
 inline long addsl2(long a, long b);
 inline long addslN(size_t n, long addend[n]);
 
-inline int cmpl(const void *p1, const void *p2);
-
 
 inline long
 addsl2(long a, long b)
@@ -57,7 +55,7 @@ addslN(size_t n, long addend[n])
 
 	e = errno;
 	while (n > 1) {
-		qsort(addend, n, sizeof(addend[0]), cmpl);
+		QSORT(addend, n);
 
 		errno = 0;
 		addend[0] = addsl2(addend[0], addend[--n]);
@@ -69,18 +67,4 @@ addslN(size_t n, long addend[n])
 }
 
 
-inline int
-cmpl(const void *p1, const void *p2)
-{
-	const long  *l1 = p1;
-	const long  *l2 = p2;
-
-	if (*l1 < *l2)
-		return -1;
-	if (*l1 > *l2)
-		return +1;
-	return 0;
-}
-
-
 #endif  // include guard
