@@ -17,9 +17,11 @@
 #include <sys/time.h>
 #include <fcntl.h>
 #include <stdio.h>
+#include <string.h>
 
-#include "alloc.h"
+#include "alloc/x/xmalloc.h"
 #include "attr.h"
+#include "fs/readlink/areadlink.h"
 #include "prototypes.h"
 #include "defines.h"
 #ifdef WITH_SELINUX
@@ -36,7 +38,8 @@
 #include <attr/libattr.h>
 #endif				/* WITH_ATTR */
 #include "shadowlog.h"
-#include "string/sprintf.h"
+#include "string/sprintf/xasprintf.h"
+#include "string/strcmp/streq.h"
 
 
 static /*@null@*/const char *src_orig;
@@ -66,7 +69,6 @@ static int copy_dir (const struct path_info *src, const struct path_info *dst,
                      const struct stat *statp, const struct timespec mt[],
                      uid_t old_uid, uid_t new_uid,
                      gid_t old_gid, gid_t new_gid);
-static /*@null@*/char *readlink_malloc (const char *filename);
 static int copy_symlink (const struct path_info *src, const struct path_info *dst,
                          MAYBE_UNUSED bool reset_selinux,
                          const struct stat *statp, const struct timespec mt[],
@@ -313,8 +315,8 @@ static int copy_tree_impl (const struct path_info *src, const struct path_info *
 		/*
 		 * Skip the "." and ".." entries
 		 */
-		if (strcmp(ent->d_name, ".") == 0 ||
-		    strcmp(ent->d_name, "..") == 0)
+		if (streq(ent->d_name, ".") ||
+		    streq(ent->d_name, ".."))
 		{
 			continue;
 		}
@@ -536,42 +538,6 @@ static int copy_dir (const struct path_info *src, const struct path_info *dst,
 	return err;
 }
 
-/*
- * readlink_malloc - wrapper for readlink
- *
- * return NULL on error.
- * The return string shall be freed by the caller.
- */
-static /*@null@*/char *readlink_malloc (const char *filename)
-{
-	size_t size = 1024;
-
-	while (true) {
-		ssize_t nchars;
-		char *buffer = MALLOC(size, char);
-		if (NULL == buffer) {
-			return NULL;
-		}
-
-		nchars = readlink (filename, buffer, size);
-
-		if (nchars < 0) {
-			free(buffer);
-			return NULL;
-		}
-
-		if ((size_t) nchars < size) { /* The buffer was large enough */
-			/* readlink does not nul-terminate */
-			buffer[nchars] = '\0';
-			return buffer;
-		}
-
-		/* Try again with a bigger buffer */
-		free (buffer);
-		size *= 2;
-	}
-}
-
 /*
  * copy_symlink - copy a symlink
  *
@@ -602,10 +568,9 @@ static int copy_symlink (const struct path_info *src, const struct path_info *ds
 	 * destination directory name.
 	 */
 
-	oldlink = readlink_malloc (src->full_path);
-	if (NULL == oldlink) {
+	oldlink = areadlink(src->full_path);
+	if (NULL == oldlink)
 		return -1;
-	}
 
 	/* If src was a link to an entry of the src_orig directory itself,
 	 * create a link to the corresponding entry in the dst_orig
