@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2024, Alejandro Colomar <alx@kernel.org>
+// SPDX-FileCopyrightText: 2024-2025, Alejandro Colomar <alx@kernel.org>
 // SPDX-License-Identifier: BSD-3-Clause
 
 
@@ -9,7 +9,6 @@
 #include <config.h>
 
 #include <errno.h>
-#include <stddef.h>
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -23,30 +22,28 @@
 
 ATTR_STRING(1)
 inline ssize_t readlinknul(const char *restrict link, char *restrict buf,
-    size_t size);
+    ssize_t size);
 
 
 // Similar to readlink(2), but terminate the string.
 inline ssize_t
-readlinknul(const char *restrict link, char *restrict buf, size_t size)
+readlinknul(const char *restrict link, char *restrict buf, ssize_t size)
 {
-	size_t   ulen;
-	ssize_t  slen;
+	ssize_t  len;
 
-	slen = readlink(link, buf, size);
-	if (slen == -1)
+	len = readlink(link, buf, size);
+	if (len == -1)
 		return -1;
 
-	ulen = slen;
-	if (ulen == size) {
+	if (len == size) {
 		stpcpy(&buf[size-1], "");
 		errno = E2BIG;
 		return -1;
 	}
 
-	stpcpy(&buf[ulen], "");
+	stpcpy(&buf[len], "");
 
-	return slen;
+	return len;
 }
 
 
