@@ -15,9 +15,8 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "alloc.h"
 #include "getdef.h"
-#include "string/sprintf.h"
+#include "string/sprintf/xasprintf.h"
 
 #ident "$Id$"
 
