@@ -48,16 +48,15 @@ static const char *PROMPT = gettext_noop ("%s's Password: ");
  *	compared.
  */
 
-int pw_auth (const char *cipher,
-             const char *user,
-             int reason,
-             /*@null@*/const char *input)
+int
+pw_auth(const char *cipher, const char *user)
 {
 	int          retval;
 	char         prompt[1024];
-	char         *clear = NULL;
+	char         *clear;
 	const char   *cp;
 	const char   *encrypted;
+	const char   *input;
 
 #ifdef	SKEY
 	bool         use_skey = false;
@@ -65,35 +64,6 @@ int pw_auth (const char *cipher,
 	struct skey  skey;
 #endif
 
-	/*
-	 * There are programs for adding and deleting authentication data.
-	 */
-
-	if ((PW_ADD == reason) || (PW_DELETE == reason)) {
-		return 0;
-	}
-
-	/*
-	 * There are even programs for changing the user name ...
-	 */
-
-	if ((PW_CHANGE == reason) && (NULL != input)) {
-		return 0;
-	}
-
-	/*
-	 * WARNING:
-	 *
-	 * When we change a password and we are root, we don't prompt.
-	 * This is so root can change any password without having to
-	 * know it.  This is a policy decision that might have to be
-	 * revisited.
-	 */
-
-	if ((PW_CHANGE == reason) && (getuid () == 0)) {
-		return 0;
-	}
-
 	/*
 	 * WARNING:
 	 *
@@ -128,25 +98,22 @@ int pw_auth (const char *cipher,
 #endif
 
 	/*
-	 * Prompt for the password as required.  FTPD and REXECD both
-	 * get the cleartext password for us.
+	 * Prompt for the password as required.
 	 */
 
-	if ((PW_FTP != reason) && (PW_REXEC != reason) && (NULL == input)) {
-		cp = getdef_str ("LOGIN_STRING");
-		if (NULL == cp) {
-			cp = _(PROMPT);
-		}
+	cp = getdef_str ("LOGIN_STRING");
+	if (NULL == cp) {
+		cp = _(PROMPT);
+	}
 #ifdef	SKEY
-		if (use_skey) {
-			printf ("[%s]\n", challenge_info);
-		}
+	if (use_skey) {
+		printf ("[%s]\n", challenge_info);
+	}
 #endif
 
-		SNPRINTF(prompt, cp, user);
-		clear = agetpass(prompt);
-		input = (clear == NULL) ? "" : clear;
-	}
+	SNPRINTF(prompt, cp, user);
+	clear = agetpass(prompt);
+	input = (clear == NULL) ? "" : clear;
 
 	/*
 	 * Convert the cleartext password into a ciphertext string.
