@@ -19,10 +19,13 @@
 #include <sys/types.h>
 #include <string.h>
 
-#include "atoi/str2i.h"
+#include "atoi/a2i/a2s.h"
+#include "atoi/str2i/str2u.h"
+#include "defines.h"
 #include "prototypes.h"
 #include "shadowlog_internal.h"
-#include "defines.h"
+#include "string/strcmp/streq.h"
+#include "string/strtok/stpsep.h"
 
 
 #define	FIELDS	9
@@ -53,34 +56,21 @@ sgetspent(const char *string)
 		return NULL;	/* fail if too long */
 	}
 	strcpy (spwbuf, string);
-
-	cp = strrchr (spwbuf, '\n');
-	if (NULL != cp) {
-		*cp = '\0';
-	}
+	stpsep(spwbuf, "\n");
 
 	/*
 	 * Tokenize the string into colon separated fields.  Allow up to
 	 * FIELDS different fields.
 	 */
 
-	for (cp = spwbuf, i = 0; ('\0' != *cp) && (i < FIELDS); i++) {
-		fields[i] = cp;
-		cp = strchrnul(cp, ':');
-
-		if ('\0' != *cp) {
-			*cp = '\0';
-			cp++;
-		}
-	}
+	for (cp = spwbuf, i = 0; cp != NULL && i < FIELDS; i++)
+		fields[i] = strsep(&cp, ":");
 
 	if (i == (FIELDS - 1))
 		fields[i++] = "";
 
-	if ( ((NULL != cp) && ('\0' != *cp)) ||
-	     ((i != FIELDS) && (i != OFIELDS)) ) {
+	if (cp != NULL || (i != FIELDS && i != OFIELDS))
 		return NULL;
-	}
 
 	/*
 	 * Start populating the structure.  The fields are all in
@@ -96,34 +86,28 @@ sgetspent(const char *string)
 	 * incorrectly formatted number.
 	 */
 
-	if (fields[2][0] == '\0') {
+	if (streq(fields[2], ""))
 		spwd.sp_lstchg = -1;
-	} else if (   (str2sl(&spwd.sp_lstchg, fields[2]) == -1)
-	           || (spwd.sp_lstchg < 0)) {
+	else if (a2sl(&spwd.sp_lstchg, fields[2], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * Get the minimum period between password changes.
 	 */
 
-	if (fields[3][0] == '\0') {
+	if (streq(fields[3], ""))
 		spwd.sp_min = -1;
-	} else if (   (str2sl(&spwd.sp_min, fields[3]) == -1)
-	           || (spwd.sp_min < 0)) {
+	else if (a2sl(&spwd.sp_min, fields[3], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * Get the maximum number of days a password is valid.
 	 */
 
-	if (fields[4][0] == '\0') {
+	if (streq(fields[4], ""))
 		spwd.sp_max = -1;
-	} else if (   (str2sl(&spwd.sp_max, fields[4]) == -1)
-	           || (spwd.sp_max < 0)) {
+	else if (a2sl(&spwd.sp_max, fields[4], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * If there are only OFIELDS fields (this is a SVR3.2 /etc/shadow
@@ -143,47 +127,40 @@ sgetspent(const char *string)
 	 * Get the number of days of password expiry warning.
 	 */
 
-	if (fields[5][0] == '\0') {
+	if (streq(fields[5], ""))
 		spwd.sp_warn = -1;
-	} else if (   (str2sl(&spwd.sp_warn, fields[5]) == -1)
-	           || (spwd.sp_warn < 0)) {
+	else if (a2sl(&spwd.sp_warn, fields[5], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * Get the number of days of inactivity before an account is
 	 * disabled.
 	 */
 
-	if (fields[6][0] == '\0') {
+	if (streq(fields[6], ""))
 		spwd.sp_inact = -1;
-	} else if (   (str2sl(&spwd.sp_inact, fields[6]) == -1)
-	           || (spwd.sp_inact < 0)) {
+	else if (a2sl(&spwd.sp_inact, fields[6], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * Get the number of days after the epoch before the account is
 	 * set to expire.
 	 */
 
-	if (fields[7][0] == '\0') {
+	if (streq(fields[7], ""))
 		spwd.sp_expire = -1;
-	} else if (   (str2sl(&spwd.sp_expire, fields[7]) == -1)
-	           || (spwd.sp_expire < 0)) {
+	else if (a2sl(&spwd.sp_expire, fields[7], NULL, 0, 0, LONG_MAX) == -1)
 		return NULL;
-	}
 
 	/*
 	 * This field is reserved for future use.  But it isn't supposed
 	 * to have anything other than a valid integer in it.
 	 */
 
-	if (fields[8][0] == '\0') {
+	if (streq(fields[8], ""))
 		spwd.sp_flag = SHADOW_SP_FLAG_UNSET;
-	} else if (str2ul(&spwd.sp_flag, fields[8]) == -1) {
+	else if (str2ul(&spwd.sp_flag, fields[8]) == -1)
 		return NULL;
-	}
 
 	return (&spwd);
 }
