@@ -36,9 +36,9 @@
 	/* Do the same as the other _dup function, even if we know the
 	 * structure. */
 	/*@-mustfreeonly@*/
-	sg->sg_name = strdup (sgent->sg_name);
+	sg->sg_namp = strdup (sgent->sg_namp);
 	/*@=mustfreeonly@*/
-	if (NULL == sg->sg_name) {
+	if (NULL == sg->sg_namp) {
 		free (sg);
 		return NULL;
 	}
@@ -46,7 +46,7 @@
 	sg->sg_passwd = strdup (sgent->sg_passwd);
 	/*@=mustfreeonly@*/
 	if (NULL == sg->sg_passwd) {
-		free (sg->sg_name);
+		free (sg->sg_namp);
 		free (sg);
 		return NULL;
 	}
@@ -57,7 +57,7 @@
 	/*@=mustfreeonly@*/
 	if (NULL == sg->sg_adm) {
 		free (sg->sg_passwd);
-		free (sg->sg_name);
+		free (sg->sg_namp);
 		free (sg);
 		return NULL;
 	}
@@ -69,7 +69,7 @@
 			}
 			free (sg->sg_adm);
 			free (sg->sg_passwd);
-			free (sg->sg_name);
+			free (sg->sg_namp);
 			free (sg);
 			return NULL;
 		}
@@ -86,7 +86,7 @@
 		}
 		free (sg->sg_adm);
 		free (sg->sg_passwd);
-		free (sg->sg_name);
+		free (sg->sg_namp);
 		free (sg);
 		return NULL;
 	}
@@ -102,7 +102,7 @@
 			}
 			free (sg->sg_adm);
 			free (sg->sg_passwd);
-			free (sg->sg_name);
+			free (sg->sg_namp);
 			free (sg);
 			return NULL;
 		}
@@ -131,7 +131,7 @@ void
 sgr_free(/*@only@*/struct sgrp *sgent)
 {
 	size_t i;
-	free (sgent->sg_name);
+	free (sgent->sg_namp);
 	if (NULL != sgent->sg_passwd)
 		free(strzero(sgent->sg_passwd));
 
@@ -150,7 +150,7 @@ static const char *gshadow_getname (const void *ent)
 {
 	const struct sgrp *gr = ent;
 
-	return gr->sg_name;
+	return gr->sg_namp;
 }
 
 static void *gshadow_parse (const char *line)
@@ -163,7 +163,7 @@ static int gshadow_put (const void *ent, FILE * file)
 	const struct sgrp *sg = ent;
 
 	if (   (NULL == sg)
-	    || (valid_field (sg->sg_name, ":\n") == -1)
+	    || (valid_field (sg->sg_namp, ":\n") == -1)
 	    || (valid_field (sg->sg_passwd, ":\n") == -1)) {
 		return -1;
 	}
