@@ -1,13 +1,19 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
 
+
 #include <stdio.h>
-#include "subid.h"
-#include "stdlib.h"
+
+#include "atoi/getnum.h"
 #include "prototypes.h"
 #include "shadowlog.h"
+#include "stdlib.h"
+#include "string/strcmp/streq.h"
+#include "subid.h"
+
 
 static const char Prog[] = "get_subid_owners";
 
+
 static void usage(void)
 {
 	fprintf(stderr, "Usage: [-g] %s subuid\n", Prog);
@@ -18,20 +24,24 @@ static void usage(void)
 
 int main(int argc, char *argv[])
 {
-	int i, n;
-	uid_t *uids;
+	int    i, n;
+	uid_t  u;
+	uid_t  *uids;
 
 	log_set_progname(Prog);
 	log_set_logfd(stderr);
 	if (argc < 2) {
 		usage();
 	}
-	if (argc == 3 && strcmp(argv[1], "-g") == 0)
-		n = subid_get_gid_owners(atoi(argv[2]), &uids);
-	else if (argc == 2 && strcmp(argv[1], "-h") == 0)
+	if (argc == 3 && streq(argv[1], "-g")) {
+		get_uid(argv[2], &u);
+		n = subid_get_gid_owners(u, &uids);
+	} else if (argc == 2 && streq(argv[1], "-h")) {
 		usage();
-	else
-		n = subid_get_uid_owners(atoi(argv[1]), &uids);
+	} else {
+		get_gid(argv[1], &u);
+		n = subid_get_uid_owners(u, &uids);
+	}
 	if (n < 0) {
 		fprintf(stderr, "No owners found\n");
 		exit(1);
