@@ -2,14 +2,17 @@
 
 #include <stdio.h>
 #include <unistd.h>
+
+#include "atoi/str2i/str2u.h"
 #include "subid.h"
 #include "stdlib.h"
 #include "prototypes.h"
 #include "shadowlog.h"
 
+
 /* Test program for the subid creation routine */
 
-const char *Prog;
+static const char Prog[] = "new_subid_range";
 
 static void usage(void)
 {
@@ -28,7 +31,6 @@ int main(int argc, char *argv[])
 	bool group = false;   // get subuids by default
 	bool ok;
 
-	Prog = Basename (argv[0]);
 	log_set_progname(Prog);
 	log_set_logfd(stderr);
 	while ((c = getopt(argc, argv, "gn")) != EOF) {
@@ -46,7 +48,7 @@ int main(int argc, char *argv[])
 	range.start = 0;
 	range.count = 65536;
 	if (argc > 1)
-		range.count = atoi(argv[1]);
+		str2ul(&range.count, argv[1]);
 	if (group)
 		ok = subid_grant_gid_range(&range, !makenew);
 	else
